@@ -1,15 +1,15 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
+
+use v5.20;
+use warnings;
+use Object::Pad 0.805;
+
+package Tickit::Style 0.56;
 
-use Object::Pad 0.51;
-
-package Tickit::Style 0.53;
-
-use strict;
 use warnings;
-use 5.010;
 use experimental 'postderef';
 
 use Carp;
@@ -125,18 +125,18 @@ behavioural actions with keypresses. These are given by a keypress key name in
 angle brackets (C<< <NAME> >>) and an action name, which is a bareword
 identifier.
 
- WidgetClass {
-   <Enter>: activate;
- }
+   WidgetClass {
+     <Enter>: activate;
+   }
 
 A special widget type name of C<*> can also be used to provide style blocks
 that will apply (at lower priority) to any type of widget. Typically these
 would be used along with classes or tags, to set application-wide styles.
 
- *:error {
-   bg: "red";
-   fg: "hi-white";
- }
+   *:error {
+     bg: "red";
+     fg: "hi-white";
+   }
 
 =head2 How Style is Determined
 
@@ -267,7 +267,7 @@ sub _ref_tagset
 
 =head2 style_definition
 
-   style_definition( $tags, %definition )
+   style_definition( $tags, %definition );
 
 In addition to any loaded stylesheets, the widget class itself can provide
 style information, via the C<style_definition> function. It provides a definition
@@ -301,7 +301,7 @@ sub style_definition
 
 =head2 style_reshape_keys
 
-   style_reshape_keys( @keys )
+   style_reshape_keys( @keys );
 
 Declares that the given list of keys are somehow responsible for determining
 the shape of the widget. If their values are changed, the C<reshape> method is
@@ -325,7 +325,7 @@ sub _reshape_keys
 
 =head2 style_reshape_textwidth_keys
 
-   style_reshape_textwidth_keys( @keys )
+   style_reshape_textwidth_keys( @keys );
 
 Declares that the given list of keys contain text, the C<textwidth()> of which
 is used to determine the shape of the widget. If their values are changed such
@@ -349,7 +349,7 @@ sub _reshape_textwidth_keys
 
 =head2 style_redraw_keys
 
-   style_redraw_keys( @keys )
+   style_redraw_keys( @keys );
 
 Declares that the given list of keys are somehow responsible for determining
 the look of the widget, but in a way that does not determine the size. If
@@ -401,7 +401,7 @@ These functions are not exported, but may be called directly.
 
 =head2 load_style
 
-   Tickit::Style->load_style( $string )
+   Tickit::Style->load_style( $string );
 
 Loads definitions from a stylesheet given in a string.
 
@@ -419,7 +419,7 @@ sub load_style
 
 =head2 load_style_file
 
-   Tickit::Style->load_style_file( $path )
+   Tickit::Style->load_style_file( $path );
 
 Loads definitions from a stylesheet file given by the path.
 
@@ -442,7 +442,7 @@ sub load_style_file
 
 =head2 load_style_from_DATA
 
-   Tickit::Style->load_style_from_DATA
+   Tickit::Style->load_style_from_DATA;
 
 A convenient shortcut for loading style definitions from the caller's C<DATA>
 filehandle.
@@ -460,7 +460,7 @@ sub load_style_from_DATA
 
 =head2 on_style_load
 
-   Tickit::Style::on_style_load( \&code )
+   Tickit::Style::on_style_load( \&code );
 
 Adds a CODE reference to be invoked after either C<load_style> or
 C<load_style_file> are called. This may be useful to flush any caches or
@@ -479,8 +479,8 @@ class # hide from indexer
 
    # A "Keyset" is the set of style keys applied to one particular set of
    # style tags
-   has $tags  :reader :param;
-   has $style :reader :param;
+   field $tags  :reader :param;
+   field $style :reader :param;
 
    method clone
    {
@@ -493,14 +493,9 @@ class # hide from indexer
 
 use experimental 'postderef';
 
-has @_keysets;
+field @_keysets;
 
-ADJUSTPARAMS
-{
-   my ( $params ) = @_;
-   $params->{keysets} and
-      @_keysets = ( delete $params->{keysets} )->@*;
-}
+ADJUST :params ( :$keysets = undef ) { @_keysets = $keysets->@* if $keysets; }
 
 method clone
 {
@@ -556,4 +551,10 @@ method keysets
    return @_keysets;
 }
 
+=head1 AUTHOR
+
+Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
 0x55AA;
