@@ -1,15 +1,16 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2023 -- leonerd@leonerd.org.uk
 
 use v5.20;
-use Object::Pad 0.73 ':experimental(init_expr)';
+use warnings;
+use Object::Pad 0.807 ':experimental(inherit_field)';
 
-package Tickit::Widget::LinearSplit 0.37;
-class Tickit::Widget::LinearSplit
-   :strict(params)
-   :isa(Tickit::ContainerWidget);
+package Tickit::Widget::LinearSplit 0.38;
+class Tickit::Widget::LinearSplit :strict(params);
+
+inherit Tickit::ContainerWidget;
 
 use Tickit::Window 0.32; # needs drag_start
 
@@ -19,8 +20,8 @@ field $_split_fraction = 0.5;
 field $_A_child :reader;
 field $_B_child :reader;
 
-field $_split_at;  method _split_at  { $_split_at }
-field $_split_len; method _split_len { $_split_len }
+field $_split_at  :inheritable;
+field $_split_len :inheritable;
 
 method set_A_child
 {
